#!/usr/bin/env python3
'''
Python script to split stacked pem into cert+ca and secret.

az_script-01-git.manifest.sh installs python3 -m pip pem
'''
import pem
import sys
#import os

if len(sys.argv) != 3:
    print("Err: need two argument, pem file name. and base output file name + .pem/.key")
    sys.exit(1)

file_in = sys.argv[1]
f_out_base = sys.argv[2]
certs = pem.parse_file( file_in )
# for method in dir(object):
#     print("method:",method)
cnt_key = 0
cnt_cert = 0
with open(f"{f_out_base}.key", 'w') as fk, open(f"{f_out_base}.pem", 'w') as fc:
    for cert in certs:
        #print("cert:", cert, type(cert).__name__)
        if type(cert).__name__ == "PrivateKey":
            fk.write(cert.as_text())
            cnt_key +=1
        elif type(cert).__name__ == "Certificate":
            fc.write(cert.as_text())
            cnt_cert +=1
        else:
            print(f"Err: file {file_in} contained section of unkown type={type(cert).__name__} ")
            sys.exit(1)
# print()

print(f"created files with base {f_out_base}(.key|.pem), {cnt_key} key and {cnt_cert} certs")
if (cnt_key < 1) or (cnt_cert < 1):
    print("Error key or cert missing.")
    sys.exit(1)
print(f"The END. {sys.argv[0]}")



#!/usr/bin/env python3.6
print("# pip3.6 install azure-cli --user ")
import os
import sys
import datetime
import pytz
from collections import OrderedDict

from azure.cli.core import get_default_cli
#from azhelper import az_cli
from pprint import pprint as pp

def az_cli (args, debug = False):
    ''' args list or string '''
    if isinstance(args, str):
        args = args.split()
    cli = get_default_cli()
    if debug:
        cli.invoke(args)
    else:
        cli.invoke(args, out_file = open(os.devnull, 'w'))

    if cli.result.result:
        return cli.result.result
    elif cli.result.error:
        print(f"Got cli.result.error: {cli.result.error}")
        raise cli.result.error
    return list() # was True

vm_ids = list()
vm_info_by_region = dict()
print(f"got  {len(vm_ids)}vm's, Now vm list ...")
for azsub in [ "Infrastructure", "Prod", "Non-Prod" ]:
    print(f"... az vm list --subscription '{azsub}' ...\r" , end ="")
    #azr = az_cli( ["vm", "list", "--subscription", azsub, "-o", "json"] )
    azr = az_cli( ["vm", "list", "--subscription", azsub, "--query", "[].id", "-o", "tsv"] )
    print(f"vm's: {azsub:<18}, {len(azr)} {' '*20}")
    #print(f"azr={azr}")
    vm_ids.extend( azr )

    cmd = ["vm", "show","-o", "json", "--show-details", "--ids" ]
    cmd.extend( azr )
    print(f"... az vm show --show-details --ids {len(azr)} ...\r" , end ="")
    azr2 = az_cli(cmd )
    if len(azr) == 1:
        #print("azr len =1: azr2:",azr2)
        azr3 = list()
        azr3.append(azr2) #Put single dict in list
        azr2 = azr3
    #pp(azr2)
    for vm in azr2:
        #print("__vm__top") ; pp(vm) ; print("__vm__bottom")
        print( f" 1x {vm['hardwareProfile']['vmSize']:<15}, {vm['location']}, {vm['resourceGroup']}, "+
                f"State:\"{vm['powerState']}\", pubIp:{vm['publicIps']}, "
                )
        # make sure w
        vm_info_by_region.setdefault(vm['location'], dict() )
        tmp_count = vm_info_by_region[vm['location']].setdefault(vm['hardwareProfile']['vmSize'],0)
        vm_info_by_region[vm['location']][vm['hardwareProfile']['vmSize']] = tmp_count + 1

print(f"got  {len(vm_ids)} non k8s vm's")
#
for azsub in [ "Infrastructure", "Prod", "Non-Prod" ]:
    #az vmss list --subscription "Prod"
    print(f"... az vmss list --subscription '{azsub}' ...\r" , end ="")
    azr = az_cli( ["vmss", "list", "--subscription", azsub, "-o", "json" ] )
    print(f"vmss k8s found: '{azsub}'{' '*(18-len(azsub))}, {len(azr)} size:{sys.getsizeof(azr)} {' '*20}")
    for vmss in azr:
        print(f" {vmss['sku']['capacity']}x {vmss['sku']['name']:<15}, {vmss['location']},"+
              f" vmss:{vmss['name']}, {vmss['resourceGroup']},"+
              f" \"{azsub}\", State:{vmss['provisioningState']}"
             )
        vm_info_by_region.setdefault(vmss['location'], dict() )
        tmp_count = vm_info_by_region[vmss['location']].setdefault(vmss['sku']['name'],0)
        vm_info_by_region[vmss['location']][vmss['sku']['name']] = tmp_count + vmss['sku']['capacity']

#2020-01 az reservations reservation-order list  still beta with errors.
reservations = {
                "southeastasia": "3 x B4ms - VM_RI_SEA_20200128_3xB4ms till 2023-01-27",
                "australiaeast": "10 x B4ms - VM_RI_AEA_20200414_10xB4ms till  $87.77/pm/pvm 62% saving",
                "westus2":       "2 x B4ms - VM_RI_20200207_WUS2_2xB4ms till 2023",
                }
                #westus2 2xB4ms TODAY'S CHARGE 138.26 NZD  ,  TOTAL COST 4,977.36 NZD
print("Got vm info.")
# tz = datetime.timezone.utc
tz = pytz.timezone('Pacific/Auckland')
ft = "%Y-%m-%dT%H:%M:%S%z"
t = datetime.datetime.now(tz=tz).strftime(ft)
print()
print(f"== Summary {t} ==")
count_total = 0
for region,models in OrderedDict(sorted( vm_info_by_region.items() )).items():
    print(f"Region: \"{region}\"")
    count_region = 0
    for model,count in OrderedDict(sorted( models.items() )).items():
        print(f"{' '*10} {count} x {model}")
        count_region += count
    print(f"{' '*6}= {count_region} in \"{region}\"" )
    if region in reservations:
        print(f"{' '*5}RI {reservations[region]}")
    print()
    count_total += count_region
print(f"{' '*1}{count_total} total servers in azure (+ mongoDB atlas billed seperately)" )
print()
print("The End.")






#!/usr/bin/env python3.6
print("# pip3.6 install azure-cli --user ")
import os
import sys
import datetime
import pytz
import collections  # to use OrderedDict, DefaultDict
import json

#from azhelper import az_cli
from pprint import pprint as pp
rootdir = "../configs/tokensvc-osp-config"
if not os.path.exists(rootdir):
    rootdir = "configs/tokensvc-osp-config"

#Get dirs
maindirs = [ d for d in os.scandir(rootdir) if d.is_dir() ]
# print("maindirs:",maindirs)
data = collections.defaultdict(dict)  # simplified dict in dict
data_envs = set()
data_channels = set()
data_osps = set()
for env in maindirs:
    data_channels.add(env.name)
    #print(env.name)
    for subdir, dirs , files in os.walk( env , topdown=True):
        for file in files:
            filename, file_extension = os.path.splitext(file)
            data_envs.add(filename)
            # print(env.name, filename, file_extension , subdir)
            with open( os.path.join(subdir,file), 'r') as f:
                j = json.load(f)
                for entry in j:
                    data_osps.add(entry['osp'])
                    #print("entry",entry, env.name + "-" + filename)
                    data[ entry['osp'] ][ env.name + "-" + filename ] = entry


print("data_envs",data_envs)
print("data_channels",data_channels)
print("data_osps",data_osps)

def genOSPtable():
    print()
    print("Start - print wiki page ..")
    header = "| Env"
    header_break = "|--"
    for o in data_osps:
        header = header + " | " + o
        header_break = header_break + "|--"
    header = header + " |"
    header_break = header_break + "|"
    print(header)
    print(header_break)
    for c in data_channels:
        for e in data_envs:
            line = "| " + f"{c}-{e}"
            for o in data_osps:
                if f"{c}-{e}" in data[ o ]:
                    client_id = data[ o ][ f"{c}-{e}" ].get('client_id',f"No {o} client_id")
                    line = line + " | client_id:\"" + client_id + '"'

                    for note in [ key for key in data[ o ][f"{c}-{e}"] if key.startswith("note") ]:
                        line = line + ", " + note + ':"' + data[ o ][ f"{c}-{e}" ][ note ] + '"'
                else:
                    line = line + " | " + "n.a."
                    #print( data[o] , f"{c}-{e}" )
            else:
                line = line + " |"
            print(line)
    print( header)  # at bottom again
    print()
###########################
def genENVtable():
    print()
    print("Start - print wiki page ..")
    header = "| OSP"
    header_break = "|--"
    for c in sorted(data_channels):
        for e in sorted(data_envs):
            header = header + " | " + f"{c}-{e}"
            header_break = header_break + "|--"
    header = header + " | OSP |"
    header_break = header_break + "|--|"
    print(header)
    print(header_break)
    for o in sorted(data_osps):
        line = "| osp:" + o
        for c in sorted(data_channels):
            for e in sorted(data_envs):
                if f"{c}-{e}" in data[ o ]:
                    for id_name in ["client_id", "consumer_key"]:
                        if id_name in data[ o ][ f"{c}-{e}" ]:
                            id = data[ o ][ f"{c}-{e}" ][ id_name ]
                            id = id[0:3] + ".." + id[-3:]
                            line = line + " | " + id_name + ':"' + id + '"'
                            break
                    else:
                        line = line + " | NO " + o + ' id'
                    for note in [ key for key in data[ o ][f"{c}-{e}"] if key.startswith("note") ]:
                        line = line + ", " + note + ':"' + data[ o ][ f"{c}-{e}" ][ note ] + '"'
                else:
                    line = line + " | " + "n.a."
                    #print( data[o] , f"{c}-{e}" )

        else:
            line = line + " | osp:" + o + " |"
        print(line)
    print( header)  # at bottom again
    print()


# genOSPtable()
genENVtable()
#print(data_osps)
print("The End.")






#!/usr/bin/env python3
'''
Pieter Smit 2020-07
$ export EDITOR=/home/pieter/git/helmchart/k8sAzure/k8s-rotate-pwd-in-file.py
$ sops /env/nspreact/dev/secrets.yaml
'''
import sys
import os
import re
#print("argv",sys.argv)
with open(sys.argv[1], "r") as f:
    data = f.readlines()
countReplacement = 0
with open(sys.argv[1], "w") as f:
    for l in data:
        if "creds_password:" in l:
            countReplacement += 1
            # print("old:", l , end="")
            u = os.popen("openssl rand -base64 48").read().strip()
            nl = re.sub('creds_password: .+', f'creds_password: "{u}-202007"', l)
            # print("new:", nl)
        else:
            nl = l
        f.write(nl)
print(f"The End. {countReplacement} {sys.argv[1]}")


